@@ -2,7 +2,8 @@
 CIECAM16 Colour Appearance Model
 ================================
 
-Defines the *CIECAM16* colour appearance model objects:
+Define the *CIECAM16* colour appearance model for predicting perceptual colour
+attributes under varying viewing conditions.
 
 -   :class:`colour.appearance.InductionFactors_CIECAM16`
 -   :attr:`colour.VIEWING_CONDITIONS_CIECAM16`
@@ -20,12 +21,11 @@ References
 
 from __future__ import annotations
 
-from collections import namedtuple
 from dataclasses import astuple, dataclass, field
 
 import numpy as np
 
-from colour.algebra import spow, vector_dot
+from colour.algebra import spow, vecmul
 from colour.appearance.cam16 import MATRIX_16, MATRIX_INVERSE_16
 from colour.appearance.ciecam02 import (
     VIEWING_CONDITIONS_CIECAM02,
@@ -49,10 +49,17 @@ from colour.appearance.ciecam02 import (
     temporary_magnitude_quantity_inverse,
     viewing_conditions_dependent_parameters,
 )
-from colour.hints import ArrayLike, NDArrayFloat
+from colour.hints import (  # noqa: TC001
+    Annotated,
+    ArrayLike,
+    Domain100,
+    NDArrayFloat,
+    Range100,
+)
 from colour.utilities import (
     CanonicalMapping,
     MixinDataclassArithmetic,
+    MixinDataclassIterable,
     as_float,
     as_float_array,
     from_range_100,
@@ -84,11 +91,10 @@ __all__ = [
 ]
 
 
-class InductionFactors_CIECAM16(
-    namedtuple("InductionFactors_CIECAM16", ("F", "c", "N_c"))
-):
+@dataclass(frozen=True)
+class InductionFactors_CIECAM16(MixinDataclassIterable):
     """
-    *CIECAM16* colour appearance model induction factors.
+    Define the *CIECAM16* colour appearance model induction factors.
 
     Parameters
     ----------
@@ -109,12 +115,16 @@ class InductionFactors_CIECAM16(
     :cite:`CIEDivision12022`
     """
 
+    F: float
+    c: float
+    N_c: float
+
 
 VIEWING_CONDITIONS_CIECAM16: CanonicalMapping = CanonicalMapping(
     VIEWING_CONDITIONS_CIECAM02
 )
 VIEWING_CONDITIONS_CIECAM16.__doc__ = """
-Reference *CIECAM16* colour appearance model viewing conditions.
+Define the reference *CIECAM16* colour appearance model viewing conditions.
 
 References
 ----------
@@ -130,7 +140,7 @@ class CAM_Specification_CIECAM16(MixinDataclassArithmetic):
     Parameters
     ----------
     J
-        Correlate of *Lightness* :math:`J`.
+        Correlate of *lightness* :math:`J`.
     C
         Correlate of *chroma* :math:`C`.
     h
@@ -162,18 +172,19 @@ class CAM_Specification_CIECAM16(MixinDataclassArithmetic):
 
 
 def XYZ_to_CIECAM16(
-    XYZ: ArrayLike,
-    XYZ_w: ArrayLike,
+    XYZ: Domain100,
+    XYZ_w: Domain100,
     L_A: ArrayLike,
     Y_b: ArrayLike,
-    surround: InductionFactors_CIECAM02
-    | InductionFactors_CIECAM16 = VIEWING_CONDITIONS_CIECAM16["Average"],
+    surround: (
+        InductionFactors_CIECAM02 | InductionFactors_CIECAM16
+    ) = VIEWING_CONDITIONS_CIECAM16["Average"],
     discount_illuminant: bool = False,
     compute_H: bool = True,
-) -> CAM_Specification_CIECAM16:
+) -> Annotated[CAM_Specification_CIECAM16, (100, 100, 360, 100, 100, 100, 400)]:
     """
-    Compute the *CIECAM16* colour appearance model correlates from given
-    *CIE XYZ* tristimulus values.
+    Compute the *CIECAM16* colour appearance model correlates from the
+    specified *CIE XYZ* tristimulus values.
 
     Parameters
     ----------
@@ -182,22 +193,22 @@ def XYZ_to_CIECAM16(
     XYZ_w
         *CIE XYZ* tristimulus values of reference white.
     L_A
-        Adapting field *luminance* :math:`L_A` in :math:`cd/m^2`, (often taken
-        to be 20% of the luminance of a white object in the scene).
+        Adapting field *luminance* :math:`L_A` in :math:`cd/m^2`, (often
+        taken to be 20% of the luminance of a white object in the scene).
     Y_b
         Luminous factor of background :math:`Y_b` such as
-        :math:`Y_b = 100 x L_b / L_w` where :math:`L_w` is the luminance of the
-        light source and :math:`L_b` is the luminance of the background. For
-        viewing images, :math:`Y_b` can be the average :math:`Y` value for the
-        pixels in the entire image, or frequently, a :math:`Y` value of 20,
-        approximate an :math:`L^*` of 50 is used.
+        :math:`Y_b = 100 \\times L_b / L_w` where :math:`L_w` is the
+        luminance of the light source and :math:`L_b` is the luminance of
+        the background. For viewing images, :math:`Y_b` can be the average
+        :math:`Y` value for the pixels in the entire image, or frequently,
+        a :math:`Y` value of 20, approximate an :math:`L^*` of 50 is used.
     surround
         Surround viewing conditions induction factors.
     discount_illuminant
         Truth value indicating if the illuminant should be discounted.
     compute_H
-        Whether to compute *Hue* :math:`h` quadrature :math:`H`. :math:`H` is
-        rarely used, and expensive to compute.
+        Whether to compute *Hue* :math:`h` quadrature :math:`H`.
+        :math:`H` is rarely used, and expensive to compute.
 
     Returns
     -------
@@ -206,48 +217,31 @@ def XYZ_to_CIECAM16(
 
     Notes
     -----
-    +------------+-----------------------+---------------+
-    | **Domain** | **Scale - Reference** | **Scale - 1** |
-    +============+=======================+===============+
-    | ``XYZ``    | [0, 100]              | [0, 1]        |
-    +------------+-----------------------+---------------+
-    | ``XYZ_w``  | [0, 100]              | [0, 1]        |
-    +------------+-----------------------+---------------+
+    +---------------------+-----------------------+---------------+
+    | **Domain**          | **Scale - Reference** | **Scale - 1** |
+    +=====================+=======================+===============+
+    | ``XYZ``             | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``XYZ_w``           | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
 
-    +----------------------------------+-----------------------\
-+---------------+
-    | **Range**                        | **Scale - Reference** \
-| **Scale - 1** |
-    +==================================+=======================\
-+===============+
-    | ``CAM_Specification_CIECAM16.J`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.C`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.h`` | [0, 360]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.s`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.Q`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.M`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.H`` | [0, 400]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
+    +---------------------+-----------------------+---------------+
+    | **Range**           | **Scale - Reference** | **Scale - 1** |
+    +=====================+=======================+===============+
+    | ``specification.J`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.C`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.h`` | 360                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.s`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.Q`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.M`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.H`` | 400                   | 1             |
+    +---------------------+-----------------------+---------------+
 
     References
     ----------
@@ -274,7 +268,7 @@ H=275.5949861..., HC=None)
 
     # Step 0
     # Converting *CIE XYZ* tristimulus values to sharpened *RGB* values.
-    RGB_w = vector_dot(MATRIX_16, XYZ_w)
+    RGB_w = vecmul(MATRIX_16, XYZ_w)
 
     # Computing degree of adaptation :math:`D`.
     D = (
@@ -283,24 +277,20 @@ H=275.5949861..., HC=None)
         else ones(L_A.shape)
     )
 
-    n, F_L, N_bb, N_cb, z = viewing_conditions_dependent_parameters(
-        Y_b, Y_w, L_A
-    )
+    n, F_L, N_bb, N_cb, z = viewing_conditions_dependent_parameters(Y_b, Y_w, L_A)
 
     D_RGB = D[..., None] * 100 / RGB_w + 1 - D[..., None]
     RGB_wc = D_RGB * RGB_w
 
     # Applying forward post-adaptation non-linear response compression.
-    RGB_aw = post_adaptation_non_linear_response_compression_forward(
-        RGB_wc, F_L
-    )
+    RGB_aw = post_adaptation_non_linear_response_compression_forward(RGB_wc, F_L)
 
     # Computing achromatic responses for the whitepoint.
     A_w = achromatic_response_forward(RGB_aw, N_bb)
 
     # Step 1
     # Converting *CIE XYZ* tristimulus values to sharpened *RGB* values.
-    RGB = vector_dot(MATRIX_16, XYZ)
+    RGB = vecmul(MATRIX_16, XYZ)
 
     # Step 2
     RGB_c = D_RGB * RGB
@@ -347,36 +337,40 @@ H=275.5949861..., HC=None)
     s = saturation_correlate(M, Q)
 
     return CAM_Specification_CIECAM16(
-        as_float(from_range_100(J)),
-        as_float(from_range_100(C)),
-        as_float(from_range_degrees(h)),
-        as_float(from_range_100(s)),
-        as_float(from_range_100(Q)),
-        as_float(from_range_100(M)),
-        as_float(from_range_degrees(H, 400)),
-        None,
+        J=as_float(from_range_100(J)),
+        C=as_float(from_range_100(C)),
+        h=as_float(from_range_degrees(h)),
+        s=as_float(from_range_100(s)),
+        Q=as_float(from_range_100(Q)),
+        M=as_float(from_range_100(M)),
+        H=as_float(from_range_degrees(H, 400)),
+        HC=None,
     )
 
 
 def CIECAM16_to_XYZ(
-    specification: CAM_Specification_CIECAM16,
-    XYZ_w: ArrayLike,
+    specification: Annotated[
+        CAM_Specification_CIECAM16, (100, 100, 360, 100, 100, 100, 400)
+    ],
+    XYZ_w: Domain100,
     L_A: ArrayLike,
     Y_b: ArrayLike,
-    surround: InductionFactors_CIECAM02
-    | InductionFactors_CIECAM16 = VIEWING_CONDITIONS_CIECAM16["Average"],
+    surround: (
+        InductionFactors_CIECAM02 | InductionFactors_CIECAM16
+    ) = VIEWING_CONDITIONS_CIECAM16["Average"],
     discount_illuminant: bool = False,
-) -> NDArrayFloat:
+) -> Range100:
     """
-    Convert from *CIECAM16* specification to *CIE XYZ* tristimulus values.
+    Convert the *CIECAM16* colour appearance model specification to *CIE XYZ*
+    tristimulus values.
 
     Parameters
     ----------
     specification
         *CIECAM16* colour appearance model specification. Correlate of
-        *Lightness* :math:`J`, correlate of *chroma* :math:`C` or correlate of
+        *lightness* :math:`J`, correlate of *chroma* :math:`C` or correlate of
         *colourfulness* :math:`M` and *hue* angle :math:`h` in degrees must be
-        specified, e.g. :math:`JCh` or :math:`JMh`.
+        specified, e.g., :math:`JCh` or :math:`JMh`.
     XYZ_w
         *CIE XYZ* tristimulus values of reference white.
     L_A
@@ -384,11 +378,11 @@ def CIECAM16_to_XYZ(
         to be 20% of the luminance of a white object in the scene).
     Y_b
         Luminous factor of background :math:`Y_b` such as
-        :math:`Y_b = 100 x L_b / L_w` where :math:`L_w` is the luminance of the
-        light source and :math:`L_b` is the luminance of the background. For
-        viewing images, :math:`Y_b` can be the average :math:`Y` value for the
-        pixels in the entire image, or frequently, a :math:`Y` value of 20,
-        approximate an :math:`L^*` of 50 is used.
+        :math:`Y_b = 100 \\times L_b / L_w` where :math:`L_w` is the luminance
+        of the light source and :math:`L_b` is the luminance of the background.
+        For viewing images, :math:`Y_b` can be the average :math:`Y` value for
+        the pixels in the entire image, or frequently, a :math:`Y` value of 20,
+        approximating an :math:`L^*` of 50 is used.
     surround
         Surround viewing conditions.
     discount_illuminant
@@ -407,50 +401,31 @@ def CIECAM16_to_XYZ(
 
     Notes
     -----
-    +----------------------------------+-----------------------\
-+---------------+
-    | **Domain**                       | **Scale - Reference** \
-| **Scale - 1** |
-    +==================================+=======================\
-+===============+
-    | ``CAM_Specification_CIECAM16.J`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.C`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.h`` | [0, 360]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.s`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.Q`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.M`` | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``CAM_Specification_CIECAM16.H`` | [0, 360]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
-    | ``XYZ_w``                        | [0, 100]              \
-| [0, 1]        |
-    +----------------------------------+-----------------------\
-+---------------+
+    +---------------------+-----------------------+---------------+
+    | **Domain**          | **Scale - Reference** | **Scale - 1** |
+    +=====================+=======================+===============+
+    | ``specification.J`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.C`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.h`` | 360                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.s`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.Q`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.M`` | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``specification.H`` | 360                   | 1             |
+    +---------------------+-----------------------+---------------+
+    | ``XYZ_w``           | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
 
-    +-----------+-----------------------+---------------+
-    | **Range** | **Scale - Reference** | **Scale - 1** |
-    +===========+=======================+===============+
-    | ``XYZ``   | [0, 100]              | [0, 1]        |
-    +-----------+-----------------------+---------------+
+    +---------------------+-----------------------+---------------+
+    | **Range**           | **Scale - Reference** | **Scale - 1** |
+    +=====================+=======================+===============+
+    | ``XYZ``             | 100                   | 1             |
+    +---------------------+-----------------------+---------------+
 
     References
     ----------
@@ -480,7 +455,7 @@ def CIECAM16_to_XYZ(
 
     # Step 0
     # Converting *CIE XYZ* tristimulus values to sharpened *RGB* values.
-    RGB_w = vector_dot(MATRIX_16, XYZ_w)
+    RGB_w = vecmul(MATRIX_16, XYZ_w)
 
     # Computing degree of adaptation :math:`D`.
     D = (
@@ -489,17 +464,13 @@ def CIECAM16_to_XYZ(
         else ones(L_A.shape)
     )
 
-    n, F_L, N_bb, N_cb, z = viewing_conditions_dependent_parameters(
-        Y_b, Y_w, L_A
-    )
+    n, F_L, N_bb, N_cb, z = viewing_conditions_dependent_parameters(Y_b, Y_w, L_A)
 
     D_RGB = D[..., None] * 100 / RGB_w + 1 - D[..., None]
     RGB_wc = D_RGB * RGB_w
 
     # Applying forward post-adaptation non-linear response compression.
-    RGB_aw = post_adaptation_non_linear_response_compression_forward(
-        RGB_wc, F_L
-    )
+    RGB_aw = post_adaptation_non_linear_response_compression_forward(RGB_wc, F_L)
 
     # Computing achromatic responses for the whitepoint.
     A_w = achromatic_response_forward(RGB_aw, N_bb)
@@ -508,11 +479,13 @@ def CIECAM16_to_XYZ(
     if has_only_nan(C) and not has_only_nan(M):
         C = M / spow(F_L, 0.25)
     elif has_only_nan(C):
-        raise ValueError(
+        error = (
             'Either "C" or "M" correlate must be defined in '
             'the "CAM_Specification_CIECAM16" argument!'
         )
 
+        raise ValueError(error)
+
     # Step 2
     # Computing temporary magnitude quantity :math:`t`.
     t = temporary_magnitude_quantity_inverse(C, J, n)
@@ -544,7 +517,7 @@ def CIECAM16_to_XYZ(
     RGB = RGB_c / D_RGB
 
     # Step 7
-    XYZ = vector_dot(MATRIX_INVERSE_16, RGB)
+    XYZ = vecmul(MATRIX_INVERSE_16, RGB)
 
     return from_range_100(XYZ)
 
@@ -568,8 +541,8 @@ def f_e_forward(RGB_c: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
     Notes
     -----
     -   This definition is different from :cite:`Li2017` and provides linear
-        extensions under 0.26 and above 150. It also omits the 0.1 offset that
-        is now part of the general model.
+        extensions under 0.26 and above 150. It also omits the 0.1 offset
+        that is now part of the general model.
 
     Examples
     --------
@@ -605,7 +578,8 @@ def f_e_forward(RGB_c: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
 
 def f_e_inverse(RGB_a: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
     """
-    Compute the modified cone-like responses.
+    Compute the inverse of the forward eccentricity factor modified cone-like
+    responses.
 
     Parameters
     ----------
@@ -622,8 +596,8 @@ def f_e_inverse(RGB_a: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
     Notes
     -----
     -   This definition is different from :cite:`Li2017` and provides linear
-        extensions under 0.26 and above 150. It also omits the 0.1 offset that
-        is now part of the general model.
+        extensions under 0.26 and above 150. It also omits the 0.1 offset
+        that is now part of the general model.
 
     Examples
     --------
@@ -650,9 +624,7 @@ def f_e_inverse(RGB_a: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
         ],
         [
             q_U + (RGB_a - f_q_F_L_q_U) / d_f_q_F_L_q_U,
-            100
-            / F_L[..., None]
-            * spow((27.13 * RGB_a) / (400 - RGB_a), 1 / 0.42),
+            100 / F_L[..., None] * spow((27.13 * RGB_a) / (400 - RGB_a), 1 / 0.42),
             q_L * RGB_a / f_q_F_L_q_L,
         ],
     )
@@ -660,7 +632,7 @@ def f_e_inverse(RGB_a: ArrayLike, F_L: ArrayLike) -> NDArrayFloat:
 
 def f_q(F_L: ArrayLike, q: ArrayLike) -> NDArrayFloat:
     """
-    Define the :math:`f(q)` function.
+    Evaluate the :math:`f(q)` function for chromatic adaptation.
 
     Parameters
     ----------
@@ -672,7 +644,7 @@ def f_q(F_L: ArrayLike, q: ArrayLike) -> NDArrayFloat:
     Returns
     -------
     :class:`numpy.ndarray`
-        Evaluated :math:`f(q)` function.
+        Evaluated :math:`f(q)` function result.
 
     Examples
     --------
@@ -690,7 +662,7 @@ def f_q(F_L: ArrayLike, q: ArrayLike) -> NDArrayFloat:
 
 def d_f_q(F_L: ArrayLike, q: ArrayLike) -> NDArrayFloat:
     """
-    Define the :math:`f'(q)` function derivative.
+    Compute the :math:`f'(q)` function derivative.
 
     Parameters
     ----------
