@@ -1,12 +1,13 @@
-"""Showcase colour models volume and gamut plotting examples."""
+"""
+Demonstrate colour models volume and gamut plotting.
+
+This module provides examples of plotting RGB colourspace volumes and
+gamuts in various reference colourspaces.
+"""
 
 import numpy as np
 
-from colour.plotting import (
-    colour_style,
-    plot_RGB_colourspaces_gamuts,
-    plot_RGB_scatter,
-)
+from colour.plotting import colour_style, plot_RGB_colourspaces_gamuts, plot_RGB_scatter
 from colour.utilities import message_box
 
 message_box("Colour Models Volume and Gamut Plots")
